Class: Google::Cloud::ArtifactRegistry::V1::DockerImage

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/devtools/artifactregistry/v1/artifact.rb

Overview

DockerImage represents a docker artifact. The following fields are returned as untyped metadata in the Version resource, using camelcase keys (i.e. metadata.imageSizeBytes):

  • imageSizeBytes
  • mediaType
  • buildTime

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_type::String

ArtifactType of this image, e.g. "application/vnd.example+type". If the subject_digest is set and no artifact_type is given, the media_type will be considered as the artifact_type. This field is returned as the metadata.artifactType field in the Version resource.

Returns:

  • (::String)

    ArtifactType of this image, e.g. "application/vnd.example+type". If the subject_digest is set and no artifact_type is given, the media_type will be considered as the artifact_type. This field is returned as the metadata.artifactType field in the Version resource.



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#build_time::Google::Protobuf::Timestamp

Returns The time this image was built. This field is returned as the 'metadata.buildTime' field in the Version resource. The build time is returned to the client as an RFC 3339 string, which can be easily used with the JavaScript Date constructor.

Returns:

  • (::Google::Protobuf::Timestamp)

    The time this image was built. This field is returned as the 'metadata.buildTime' field in the Version resource. The build time is returned to the client as an RFC 3339 string, which can be easily used with the JavaScript Date constructor.



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_manifests::Array<::Google::Cloud::ArtifactRegistry::V1::ImageManifest>

Returns Optional. For multi-arch images (manifest lists), this field contains the list of image manifests.

Returns:



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_size_bytes::Integer

Returns Calculated size of the image. This field is returned as the 'metadata.imageSizeBytes' field in the Version resource.

Returns:

  • (::Integer)

    Calculated size of the image. This field is returned as the 'metadata.imageSizeBytes' field in the Version resource.



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#media_type::String

Returns Media type of this image, e.g. "application/vnd.docker.distribution.manifest.v2+json". This field is returned as the 'metadata.mediaType' field in the Version resource.

Returns:

  • (::String)

    Media type of this image, e.g. "application/vnd.docker.distribution.manifest.v2+json". This field is returned as the 'metadata.mediaType' field in the Version resource.



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. registry_location, project_id, repository_name and image id forms a unique image name:projects/<project_id>/locations/<location>/repositories/<repository_name>/dockerImages/<docker_image>. For example, "projects/test-project/locations/us-west4/repositories/test-repo/dockerImages/ nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf", where "us-west4" is the registry_location, "test-project" is the project_id, "test-repo" is the repository_name and "nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf" is the image's digest.

Returns:

  • (::String)

    Required. registry_location, project_id, repository_name and image id forms a unique image name:projects/<project_id>/locations/<location>/repositories/<repository_name>/dockerImages/<docker_image>. For example, "projects/test-project/locations/us-west4/repositories/test-repo/dockerImages/ nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf", where "us-west4" is the registry_location, "test-project" is the project_id, "test-repo" is the repository_name and "nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf" is the image's digest.



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#tags::Array<::String>

Returns Tags attached to this image.

Returns:

  • (::Array<::String>)

    Tags attached to this image.



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the docker image was last updated.

Returns:



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#upload_time::Google::Protobuf::Timestamp

Returns Time the image was uploaded.

Returns:



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uri::String

Returns Required. URL to access the image. Example: us-west4-docker.pkg.dev/test-project/test-repo/nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf.

Returns:

  • (::String)

    Required. URL to access the image. Example: us-west4-docker.pkg.dev/test-project/test-repo/nginx@sha256:e9954c1fc875017be1c3e36eca16be2d9e9bccc4bf072163515467d6a823c7cf



84
85
86
87
# File 'proto_docs/google/devtools/artifactregistry/v1/artifact.rb', line 84

class DockerImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end